@@ -40,13 +40,29 @@ from argparse     import RawDescriptionHelpFormatter
 from pathlib      import Path
 from textwrap     import dedent
 
+from pyAttributes                    import Attribute
 from pyAttributes.ArgParseAttributes import ArgParseMixin, CommandAttribute, ArgumentAttribute, DefaultAttribute
 from pyTerminalUI                    import LineTerminal, Severity
 
-from pyVersioning                    import Versioning, Platforms
+from pyVersioning                    import Versioning, Platforms, Project, Compiler
 from pyVersioning.Configuration      import Configuration
 
 
+class ProjectAttributeGroup(Attribute):
+	def __call__(self, func):
+		self._AppendAttribute(func, ArgumentAttribute("--project-name",    metavar='<Name>',    dest="ProjectName",    type=str, help="Name of the project."))
+		self._AppendAttribute(func, ArgumentAttribute("--project-variant", metavar='<Variant>', dest="ProjectVariant", type=str, help="Variant of the project."))
+		return func
+
+class CompilerAttributeGroup(Attribute):
+	def __call__(self, func):
+		self._AppendAttribute(func, ArgumentAttribute("--compiler-name",    metavar='<Name>',    dest="CompilerName",    type=str, help="Used compiler."))
+		self._AppendAttribute(func, ArgumentAttribute("--compiler-version", metavar='<Version>', dest="CompilerVersion", type=str, help="Used compiler version."))
+		self._AppendAttribute(func, ArgumentAttribute("--compiler-config",  metavar='<Config>',  dest="CompilerConfig",  type=str, help="Used compiler configuration."))
+		self._AppendAttribute(func, ArgumentAttribute("--compiler-options", metavar='<Options>', dest="CompilerOptions", type=str, help="Used compiler options."))
+		return func
+
+
 class Application(LineTerminal, ArgParseMixin):
 	HeadLine = "Version file generator."
 
@@ -69,6 +85,7 @@ class Application(LineTerminal, ArgParseMixin):
 			self._config = Configuration(configFile)
 
 		self._versioning = Versioning(self)
+		self._versioning.loadDataFromConfiguration(self._config)
 		self._versioning.collectData()
 
 
@@ -101,6 +118,8 @@ class Application(LineTerminal, ArgParseMixin):
 				self.WriteError("Command {0} is unknown.".format(args.Command))
 
 	@CommandAttribute("fillout", help="Read a template and replace tokens with version information.")
+	@ProjectAttributeGroup()
+	@CompilerAttributeGroup()
 	@ArgumentAttribute(metavar='<Template file>', dest="Template", type=str, help="Template input filename.")
 	@ArgumentAttribute(metavar='<Output file>',   dest="Filename", type=str, help="Output filename.")
 	def HandleFillOut(self, args):
@@ -122,18 +141,31 @@ class Application(LineTerminal, ArgParseMixin):
 
 		self.ExitOnPreviousErrors()
 
+		self.updateProject(args)
+		self.updateCompiler(args)
+
 		self._versioning.writeSourceFile(templateFile, outputFile)
 
 	@CommandAttribute("variables", help="Print all available variables.")
+	@ProjectAttributeGroup()
+	@CompilerAttributeGroup()
 	def HandleVariables(self, args):
 		self.PrintHeadline()
 
+		self.updateProject(args)
+		self.updateCompiler(args)
+
 		for key,value in self._versioning.variables.items():
 			self.WriteNormal("{key:24}: {value}".format(key=key, value=value))
 
 	@CommandAttribute("json", help="Write all available variables as JSON.")
+	@ProjectAttributeGroup()
+	@CompilerAttributeGroup()
 	@ArgumentAttribute(metavar='<Output file>',   dest="Filename", type=str, nargs="?", help="Output filename.")
 	def HandleJSON(self, args):
+		self.updateProject(args)
+		self.updateCompiler(args)
+
 		content = dedent("""\
 		{{
 		  version: {{
@@ -149,8 +181,13 @@ class Application(LineTerminal, ArgParseMixin):
 
 
 	@CommandAttribute("yaml", help="Write all available variables as YAML.")
+	@ProjectAttributeGroup()
+	@CompilerAttributeGroup()
 	@ArgumentAttribute(metavar='<Output file>',   dest="Filename", type=str, nargs="?", help="Output filename.")
 	def HandleYAML(self, args):
+		self.updateProject(args)
+		self.updateCompiler(args)
+
 		yamlEnvironment = "\n"
 		for key, value in self._versioning.variables['env'].as_dict().items():
 			yamlEnvironment += f"    {key}: {value}\n".format(key=key, value=value)
@@ -215,6 +252,25 @@ class Application(LineTerminal, ArgParseMixin):
 		output = content.format(**self._versioning.variables, yamlEnvironment=yamlEnvironment, yamlAppVeyor=yamlAppVeyor, yamlGitHub=yamlGitHub, yamlGitLab=yamlGitLab, yamlTravis=yamlTravis)
 		self.WriteNormal(output)
 
+	def updateProject(self, args):
+		if 'project' not in self._versioning.variables:
+			self._versioning.variables['project'] = Project(args.ProjectName, args.ProjectVariant)
+		elif args.ProjectName is not None:
+			self._versioning.variables['project'].name = args.ProjectName
+
+		if args.ProjectVariant is not None:
+			self._versioning.variables['project'].variant = args.ProjectVariant
+
+	def updateCompiler(self, args):
+		if args.CompilerName is not None:
+			self._versioning.variables['build'].compiler.name = args.CompilerName
+		if args.CompilerVersion is not None:
+			self._versioning.variables['build'].compiler.version = args.CompilerVersion
+		if args.CompilerConfig is not None:
+			self._versioning.variables['build'].compiler.configuration = args.CompilerConfig
+		if args.CompilerOptions is not None:
+			self._versioning.variables['build'].compiler.options = args.CompilerOptions
+
 
 def main():
 	configFile = Path(".pyVersioning.yml")
